==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>El connector %1 no és compatible amb el sistema.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Configuració del Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Engega</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Configuració del Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connectat</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Es connecta...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Apagat</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Afegeix una disposició de teclat</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Dia i hora</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 hores</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 hores</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Configuració de l&apos;hora</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Habilita la xarxa</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Inhabilita la xarxa</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Configuració de la xarxa</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Segur que voleu eliminar %1 elements?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Aquesta acció es pot desfer.</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Dispositiu desconegut</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volum desconegut</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disc</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Desmunta-ho tot</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Llançador</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Mode de moda</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mode eficient</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>A dalt</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>A baix</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>A l&apos;esquerra</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>A la dreta</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mantén visible</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mantén ocult</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultació intel·ligent</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicació</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Connectors</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vista de multitasca</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Treu de l&apos;acoblador</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Inhabilita la connexió amb fil</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Habilita la connexió amb fil</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Inhabilita la connexió sense fil</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Habilita la connexió sense fil</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Inhabilita la xarxa</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Habilita la xarxa</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Configuració de la xarxa</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Dispositiu inhabilitat</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Connexió sense fil: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Connexió amb fil: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>No connectat</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Es connecta</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connectat però sense accés a Internet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>El cable de xarxa està desendollat.</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Xarxa sense fil</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Xarxa amb fil</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Ha fallat la connexió.</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Xarxa amb fil</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Xarxa amb fil: %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Abord</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Configuració de l&apos;energia</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacitat: %1, %2 min restants</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacitat: %1, %2 h %3 min restants</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Es carrega %1, %2 min per completar-la.</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Es carrega %1, %2 h %3 min per completar-la.</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Carregada</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacitat %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Carregant: %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacitat %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacitat: 1%, completament carregada</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Mostra l&apos;escriptori</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Treu de l&apos;acoblador</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Atura&apos;t</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hiberna</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloca</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Tanca la sessió</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Canvi de compte</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Configuració de l&apos;energia</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Dispositiu</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Activa el so</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silencia</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Configuració del so</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volum: %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>So</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Paperera</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Paperera: %1 fitxers</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Paperera: %1 fitxers</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Buit</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Safata del sistema</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Xarxa sense fil</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Xarxa sense fil: %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.12.orig.tar.xz: dde-dock-5.5.12/translations/dde-dock_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>El connector %1 no és compatible amb el sistema.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode d&apos;avió</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Engega</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Configuració del mode avió</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode d&apos;avió</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Configuració del Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Engega</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Configuració del Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connectat</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Es connecta...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Apagat</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Afegeix una disposició de teclat</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Dia i hora</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 hores</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 hores</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Configuració de l&apos;hora</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Segur que voleu eliminar %1 elements?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Aquesta acció es pot desfer.</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Dispositiu desconegut</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volum desconegut</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disc</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Desmunta-ho tot</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Llançador</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Surt del mode segur</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Acoblador - Mode segur</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>L&apos;acoblador és en mode segur. Si us plau, sortiu-ne perquè es mostri adequadament.</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Mode de moda</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mode eficient</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>A dalt</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>A baix</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>A l&apos;esquerra</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>A la dreta</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mantén visible</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mantén ocult</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultació intel·ligent</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicació</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Paràmetres de l&apos;acoblador</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Mida</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Pantalles múltiples</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Àrea de connectors</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Seleccioneu quines icones apareixen a l&apos;acoblador.</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Mode de moda</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Mode eficient</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Dalt</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>A baix</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>A l&apos;esquerra</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>A la dreta</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicació</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Mantén-lo visible</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Mantén-lo amagat</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Ocultació intel·ligent</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>petit</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>gros</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Mostra l&apos;acoblador</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>A la pantalla el cursor és</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Només a la pantalla principal</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vista de multitasca</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Treu de l&apos;acoblador</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Abord</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Configuració de l&apos;energia</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacitat: %1, %2 min restants</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacitat: %1, %2 h %3 min restants</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Es carrega %1, %2 min per completar-la.</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Es carrega %1, %2 h %3 min per completar-la.</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacitat %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Carregant: %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacitat %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacitat: 1%, completament carregada</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Acoblador</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Mostra l&apos;escriptori</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Treu de l&apos;acoblador</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Atura&apos;t</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hiberna</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloca</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Tanca la sessió</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Canvi de compte</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Configuració de l&apos;energia</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Dispositiu</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Activa el so</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silencia</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Configuració del so</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volum: %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>So</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Paperera</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Paperera: %1 fitxers</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Paperera: %1 fitxers</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Mou a la paperera</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Buit</translation>
    </message>
</context>
</TS>
